=====
sybil
=====

Automated testing for the examples in your documentation.

The latest documentation can be found at:
http://sybil.readthedocs.org/en/latest/

Development takes place here:
https://github.com/cjw296/sybil/
